﻿Type=Class
Version=3.61
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'Class module
Sub Class_Globals
	
	Private mID As String
	Private mWS As WebSocket
	
	Private mIsDate As Boolean = False
	Private mIsTime As Boolean = False
	Private mIsDateTime As Boolean = False
	
End Sub

Public Sub Initialize(WS As WebSocket, ID As String, ShowDate As Boolean, ShowTime As Boolean, TimeFormat As String)
	
	mWS = WS
	mID = ID.ToLowerCase
	
	If ShowDate = True AND ShowTime = True Then 
		mIsDateTime = True
	Else If ShowDate = True AND ShowTime = False Then 
		mIsDate = True
	Else If ShowDate = False AND ShowTime = True Then 
		mIsTime = True
	End If
		
	Dim Script As String
	
	Script = "$('#'+arguments[0]).remove();" & _
					 "var selector = $('<input />');" & _
					 "selector.attr('id', arguments[0]);" & _
					 "selector.attr('type', 'text');" & _
					 "selector.css('position', 'absolute');"

	If mIsDateTime Then
		Script = Script & "$('body').append(selector.datetimepicker({timeFormat:arguments[1]}));"
		
	Else If mIsDate Then
		Script = Script & "$('body').append(selector.datepicker({timeFormat:arguments[1]}));"
		
	Else If mIsTime Then
		Script = Script & "$('body').append(selector.timepicker({timeFormat:arguments[1]}));"
		
	End If

	mWS.Eval(Script, Array As Object(mID, TimeFormat))
	
End Sub

Sub GetID() As String
	Return mID
End Sub

' ###

Sub AddEvent(EventName As String, PreventDefault As Boolean)
	EventName = EventName.ToLowerCase
	mWS.RunFunction("b4j_addEvent", Array As Object("#" & mID, EventName, mID & "_" & EventName, PreventDefault))
End Sub

Sub RemoveEvent(EventName As String)
	EventName = EventName.ToLowerCase
	mWS.Eval("$(arguments[0]).off('" & EventName & "', $(arguments[1]))", Array As Object("#" & mID))
End Sub

Sub SetEventObjectName(EventObjectName As String, EventName As String, PreventDefault As Boolean)
	EventObjectName = EventObjectName.ToLowerCase
	EventName = EventName.ToLowerCase
	RemoveEvent(EventName)
	mWS.RunFunction("b4j_addEvent", Array As Object("#" & mID, EventName, EventObjectName & "_" & EventName, PreventDefault))
End Sub

' ###

Sub AppendTo(ElementID As String)
	mWS.Eval("$(arguments[0]).appendTo($(arguments[1]))", Array As Object("#" & mID, "#" & ElementID.ToLowerCase))
End Sub

Sub Remove()
	mWS.Eval("$(arguments[0]).remove()", Array As Object("#" & mID))
End Sub

Sub GetDate() As Future
	Return mWS.EvalWithResult("return $(arguments[0]).datepicker('getDate')", Array As Object("#" & mID))
End Sub

Sub SetDateTime(DateAndTime As String)

	If mIsDateTime Then
		mWS.Eval("$(arguments[0]).datetimepicker('setDate', arguments[1])", Array As Object("#" & mID, DateAndTime))
	Else If mIsDate Then
		mWS.Eval("$(arguments[0]).datepicker('setDate', arguments[1])", Array As Object("#" & mID, DateAndTime))
	Else If mIsTime Then
		mWS.Eval("$(arguments[0]).timepicker('setDate', arguments[1])", Array As Object("#" & mID, DateAndTime))
	End If

End Sub

Sub SetLocalization(Language)

	If Language.ToLowerCase = "en" Then Language = ""

	Dim Script As String

	If mIsDateTime Then 
	
		Script = "$(arguments[0]).datetimepicker('option', $.datepicker.regional[arguments[1]]);" & _
						 "$(arguments[0]).timepicker('option', $.timepicker.regional[arguments[1]]);"

	Else If mIsDate Then 
	
		Script = "$(arguments[0]).datepicker('option', $.datepicker.regional[arguments[1]]);"
		
	Else If mIsTime Then
	
		Script = "$(arguments[0]).timepicker('option', $.timepicker.regional[arguments[1]]);"
		
	End If
		
	mWS.Eval(Script, Array As Object("#" & mID, Language))
	
End Sub

Sub SetDateFormat(DateFormat As String)

	Dim Script As String

	If mIsDateTime Then
		Script = "$(arguments[0]).datetimepicker('option', 'dateFormat', '" & DateFormat & "');"
	Else If mIsDate Then
		Script = "$(arguments[0]).datepicker('option', 'dateFormat', '" & DateFormat & "');"
	Else If mIsTime Then
		Script = "$(arguments[0]).timepicker('option', 'dateFormat', '" & DateFormat & "');"
	End If	

	mWS.Eval(Script, Array As Object("#" & mID))

End Sub

Sub GetDisabled() As Future
	Return mWS.EvalWithResult("return $(arguments[0]).prop(arguments[1])", Array As Object("#" & mID, "disabled"))
End Sub
Sub SetDisabled(Disabled As Boolean)
	mWS.Eval("$(arguments[0]).prop(arguments[1],arguments[2])", Array As Object("#" & mID, "disabled", Disabled))
End Sub
Sub Enable()
	SetDisabled(False)
End Sub
Sub Disable()
	SetDisabled(True)
End Sub

Sub GetVisible() As Future
	Return mWS.EvalWithResult("return ($(arguments[0]).css('display')!='none')", Array As Object("#" & mID))
End Sub
Sub SetVisible(Visible As Boolean)
	If Visible = True Then
		SetCss("display", "")
	Else
		SetCss("display", "none")
	End If
End Sub

' ######################

Sub Resize(Left As String, Top As String, Width As String, Height As String)

	Dim CSS As String

	CSS = "$(arguments[0]).css({"
	
	If Left   <> -1 Then CSS = CSS & "'left':'" & Left & "px',"
	If Top    <> -1 Then CSS = CSS & "'top':'" & Top & "px',"
	If Width  <> -1 Then CSS = CSS & "'width':'" & Width & "px',"
	If Height <> -1 Then CSS = CSS & "'height':'" & Height & "px',"
	
	If CSS.EndsWith(",") Then	
	
		CSS = CSS.SubString2(0, CSS.Length - 1)
	
		CSS = CSS & "});"
	
		mWS.Eval(CSS, Array As Object("#" & mID))
		
	End If
	
End Sub

Sub GetTop() As Future
	Return GetCss("top")
End Sub
Sub SetTop(Top As String)
	SetCss("top", Top & "px")
End Sub

Sub GetLeft As Future
	Return GetCss("left")
End Sub
Sub SetLeft(Left As String)
	SetCss("left", Left & "px")
End Sub

Sub GetWidth As Future
	Return GetCss("width")
End Sub
Sub SetWidth(Width As String)
	SetCss("width", Width & "px")
End Sub

Sub GetHeight As Future
	Return GetCss("height")
End Sub
Sub SetHeight(Height As String)
	SetCss("height", Height & "px")
End Sub

' ######################

Sub GetCss(Property As String) As Future
	Return mWS.GetElementBySelector("#" & mID).GetCss(Property)
End Sub
Sub SetCss(Property As String, Value As String)
	mWS.GetElementBySelector("#" & mID).SetCss(Property, Value)
End Sub

Sub GetAttr(Property As String) As Future
	Return mWS.EvalWithResult("return $(arguments[0]).attr(arguments[1])", Array As Object("#" & mID, Property))
End Sub
Sub SetAttr(Property As String, Value As String)
	mWS.Eval("$(arguments[0]).attr(arguments[1], arguments[2])", Array As Object("#" & mID, Property, Value))
End Sub

Sub GetProp(Property As String) As Future
	Return mWS.GetElementBySelector("#" & mID).GetProp(Property)
End Sub
Sub SetProp(Property As String, Value As String)
	mWS.GetElementBySelector("#" & mID).SetProp(Property, Value)
End Sub

