﻿Type=Class
Version=3.61
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'Class module
Sub Class_Globals
	
	Private mID As String
	Private mWS As WebSocket
	Private mChartType As String
	Private mOptions As Map
	Private mData As List

End Sub

Public Sub Initialize(WS As WebSocket, ID As String, ChartType As String)

	mWS = WS
	mID = ID.ToLowerCase
	mChartType = ChartType

	If mChartType = "" Then
		mChartType = "PieChart"
	End If

	Dim Script As String

	Script = "$('#'+arguments[0]).remove();" & _
					 "var selector = $('<div />');" & _
					 "selector.attr('id', arguments[0]);" & _
					 "selector.css('position', 'absolute');" & _
					 "$('body').append(selector);" & _
					 "var chart = new google.visualization." & mChartType & "(document.getElementById(arguments[0]));" & _
					 "selector.data('chart', chart);"

	mWS.Eval(Script, Array As Object(mID))

End Sub

Sub GetID() As String
	Return mID
End Sub

' ###

Sub AddEvent(EventName As String, PreventDefault As Boolean)
	EventName = EventName.ToLowerCase
	mWS.RunFunction("b4j_addEvent", Array As Object("#" & mID, EventName, mID & "_" & EventName, PreventDefault))
End Sub

Sub RemoveEvent(EventName As String)
	EventName = EventName.ToLowerCase
	mWS.Eval("$(arguments[0]).off('" & EventName & "', $(arguments[1]))", Array As Object("#" & mID))
End Sub

Sub SetEventObjectName(EventObjectName As String, EventName As String, PreventDefault As Boolean)
	EventObjectName = EventObjectName.ToLowerCase
	EventName = EventName.ToLowerCase
	RemoveEvent(EventName)
	mWS.RunFunction("b4j_addEvent", Array As Object("#" & mID, EventName, EventObjectName & "_" & EventName, PreventDefault))
End Sub

' ###

Sub AppendTo(ElementID As String)
	mWS.Eval("$(arguments[0]).appendTo($(arguments[1]))", Array As Object("#" & mID, "#" & ElementID.ToLowerCase))
End Sub

Sub Remove()
	mWS.Eval("$(arguments[0]).remove()", Array As Object("#" & mID))
End Sub

Sub SetData(Data As List)
	mData = Data
End Sub

Sub SetOptions(Options As Map)
	mOptions = Options
End Sub

Sub DrawChart()

	Dim Script As String

	Script = "var data = google.visualization.arrayToDataTable(arguments[1]);" & CRLF & _
					 "var chart = $(arguments[0]).data('chart');" & CRLF & _
					 "chart.draw(data, arguments[2]);"

	mWS.Eval(Script, Array As Object("#" & mID, mData, mOptions))

End Sub

Sub GetVisible() As Future
	Return mWS.EvalWithResult("return ($(arguments[0]).css('display')!='none')", Array As Object("#" & mID))
End Sub
Sub SetVisible(Visible As Boolean)
	If Visible = True Then
		SetCss("display", "")
	Else
		SetCss("display", "none")
	End If
End Sub

' ######################

Sub Resize(Left As String, Top As String, Width As String, Height As String)

	Dim CSS As String

	CSS = "$(arguments[0]).css({"
	
	If Left   <> -1 Then CSS = CSS & "'left':'" & Left & "px',"
	If Top    <> -1 Then CSS = CSS & "'top':'" & Top & "px',"
	If Width  <> -1 Then CSS = CSS & "'width':'" & Width & "px',"
	If Height <> -1 Then CSS = CSS & "'height':'" & Height & "px',"
	
	If CSS.EndsWith(",") Then 
		CSS = CSS.SubString2(0, CSS.Length - 1)
		CSS = CSS & "});"
		mWS.Eval(CSS, Array As Object("#" & mID))
	End If
	
End Sub

Sub GetTop() As Future
	Return GetCss("top")
End Sub
Sub SetTop(Top As String)
	SetCss("top", Top & "px")
End Sub

Sub GetLeft As Future
	Return GetCss("left")
End Sub
Sub SetLeft(Left As String)
	SetCss("left", Left & "px")
End Sub

Sub GetWidth As Future
	Return GetCss("width")
End Sub
Sub SetWidth(Width As String)
	mWidth = Width
	SetCss("width", Width)
End Sub

Sub GetHeight As Future
	Return GetCss("height")
End Sub
Sub SetHeight(Height As String)
	mHeight = Height
	SetCss("height", Height)
End Sub

' ######################

Sub GetCss(Property As String) As Future
	Return mWS.GetElementBySelector("#" & mID).GetCss(Property)
End Sub
Sub SetCss(Property As String, Value As String)
	mWS.GetElementBySelector("#" & mID).SetCss(Property, Value)
End Sub

Sub GetAttr(Property As String) As Future
	Return mWS.EvalWithResult("return $(arguments[0]).attr(arguments[1])", Array As Object("#" & mID, Property))
End Sub
Sub SetAttr(Property As String, Value As String)
	mWS.Eval("$(arguments[0]).attr(arguments[1], arguments[2])", Array As Object("#" & mID, Property, Value))
End Sub

Sub GetProp(Property As String) As Future
	Return mWS.GetElementBySelector("#" & mID).GetProp(Property)
End Sub
Sub SetProp(Property As String, Value As String)
	mWS.GetElementBySelector("#" & mID).SetProp(Property, Value)
End Sub

