﻿Type=Class
Version=3.61
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'Class module
Sub Class_Globals
	
	Private mID As String
	Private mWS As WebSocket

End Sub

Public Sub Initialize(WS As WebSocket, ID As String)

	mWS = WS
	mID = ID.ToLowerCase

	Dim Script As String	

	Script = "$('#'+arguments[0]).remove();" & _
					 "var selector = $('<div />');" & _
					 "selector.attr('id', arguments[0]);" & _
					 "selector.css('position', 'absolute');" & _
					 "selector.css('border', '1px solid black');" & _
					 "$('body').append(selector);" & _
					 "var myOptions = {" & _
					 " center: new google.maps.LatLng(0, 0)," & _
					 " mapTypeId: google.maps.MapTypeId.SATELLITE," & _
					 " zoom: 1" & _
					 "};" & _
					 "var myMap = new google.maps.Map(selector[0], myOptions);" & _
					 "selector.data('googlemap', myMap);" & _
					 "selector.data('markerarray', new Array);"

	mWS.Eval(Script, Array As Object(mID))

End Sub

Sub GetID() As String
	Return mID
End Sub

' ###

Sub AddEvent(EventName As String, PreventDefault As Boolean)
	EventName = EventName.ToLowerCase
	mWS.RunFunction("b4j_addEvent", Array As Object("#" & mID, EventName, mID & "_" & EventName, PreventDefault))
End Sub

Sub RemoveEvent(EventName As String)
	EventName = EventName.ToLowerCase
	mWS.Eval("$(arguments[0]).off('" & EventName & "', $(arguments[1]))", Array As Object("#" & mID))
End Sub

Sub SetEventObjectName(EventObjectName As String, EventName As String, PreventDefault As Boolean)
	EventObjectName = EventObjectName.ToLowerCase
	EventName = EventName.ToLowerCase
	RemoveEvent(EventName)
	mWS.RunFunction("b4j_addEvent", Array As Object("#" & mID, EventName, EventObjectName & "_" & EventName, PreventDefault))
End Sub

' ###

Sub AppendTo(ElementID As String)
	mWS.Eval("$(arguments[0]).appendTo($(arguments[1]))", Array As Object("#" & mID, "#" & ElementID.ToLowerCase))
End Sub

Sub Remove()
	mWS.Eval("$(arguments[0]).remove()", Array As Object("#" & mID))
End Sub

Sub GetZoom() As Future

	Dim Script As String

	Script = "var myMap = $(arguments[0]).data('googlemap');" & _
					 "return myMap.getZoom();"

	Return mWS.EvalWithResult(Script, Array As Object("#" & mID))
	
End Sub
Sub SetZoom(Zoom As Int)

	Dim Script As String

	Script = "var myMap = $(arguments[0]).data('googlemap');" & _
					 "myMap.setZoom(arguments[1]);"

	mWS.Eval(Script, Array As Object("#" & mID, Zoom))

End Sub

Sub GetMapType() As Future

	Dim Script As String

	Script = "var myMap = $(arguments[0]).data('googlemap');" & _
					 "switch (myMap.getMapTypeId()) {" & _
					 " case google.maps.MapTypeId.HYBRID: return 'Hybrid';" & _
					 " case google.maps.MapTypeId.ROADMAP: return 'Roadmap';" & _
					 " case google.maps.MapTypeId.SATELLITE: return 'Satellite';" & _
					 " case google.maps.MapTypeId.TERRAIN: return 'Terrain';" & _
					 "}"

	Return mWS.EvalWithResult(Script, Array As Object("#" & mID))

End Sub
Sub SetMapType(MapType As String)

	Dim Script As String

	Script = "var myMap = $(arguments[0]).data('googlemap');"

	Select MapType.ToLowerCase
		Case "hybrid"
			Script = Script & "myMap.setMapTypeId(google.maps.MapTypeId.HYBRID);"
		Case "roadmap"
			Script = Script & "myMap.setMapTypeId(google.maps.MapTypeId.ROADMAP);"
		Case "satellite"
			Script = Script & "myMap.setMapTypeId(google.maps.MapTypeId.SATELLITE);"
		Case "terrain"
			Script = Script & "myMap.setMapTypeId(google.maps.MapTypeId.TERRAIN);"
	End Select

	mWS.Eval(Script, Array As Object("#" & mID, MapType))

End Sub

Sub SetCenter(Latitude As String, Longitude As String)

	Dim Script As String

	Script = "var myMap = $(arguments[0]).data('googlemap');" & _
					 "var center = new google.maps.LatLng(arguments[1], arguments[2]);" & _
					 "myMap.setCenter(center);"

	mWS.Eval(Script, Array As Object("#" & mID, Latitude, Longitude))

End Sub

Sub SetCenterAtMarker(Position As Int)

	Dim Script As String

	Script = "var myMap = $(arguments[0]).data('googlemap');" & _
					 "var myMarkerArray = $(arguments[0]).data('markerarray');" & _
	         "var myMarker = myMarkerArray[arguments[1]];" & _
					 "myMap.setCenter(myMarker.getPosition());"

	mWS.Eval(Script, Array As Object("#" & mID, Position))

End Sub

Sub AddMarker(Position As Int, Latitude As String, Longitude As String)

	Dim Script As String

	Script = "var myMap = $(arguments[0]).data('googlemap');" & _
					 "var myMarkerArray = $(arguments[0]).data('markerarray');" & _
					 "var myMarker = new google.maps.Marker({ map: myMap });" & _
					 "myMarker.setPosition(new google.maps.LatLng(arguments[1], arguments[2]));" & _
					 "if (arguments[3] == -1) {" & _
					 " arguments[3] = myMarkerArray.length;" & _
					 "}" & _
					 "myMarkerArray.splice(arguments[3], 0, myMarker);"

	mWS.Eval(Script, Array As Object("#" & mID, Latitude, Longitude, Position))
	
End Sub

Sub RemoveMarker(Position As Int)

	Dim Script As String

	Script = "var myMap = $(arguments[0]).data('googlemap');" & _
					 "var myMarkerArray = $(arguments[0]).data('markerarray');" & _
					 "if (myMarkerArray.length > arguments[1]) {" & _
					 " myMarkerArray[arguments[1]].setMap(null);" & _
					 " myMarkerArray.splice(arguments[1], 1);" & _
					 "}"

	mWS.Eval(Script, Array As Object("#" & mID, Position))
	
End Sub

Sub CountMarker() As Future

	Dim Script As String

	Script = "var myMap = $(arguments[0]).data('googlemap');" & _
					 "var myMarkerArray = $(arguments[0]).data('markerarray');" & _
					 "return myMarkerArray.length;"

	Return mWS.EvalWithResult(Script, Array As Object("#" & mID))
	
End Sub

Sub RequestLatLng(Address As String)

	Dim Script As String

	Script = "var geocoder = new google.maps.Geocoder();" & CRLF & _
					 "geocoder.geocode({'address':arguments[0]}, function (results, status) {" & CRLF & _
					 " if (status == google.maps.GeocoderStatus.OK) {" & CRLF & _
					 "  if (status != google.maps.GeocoderStatus.ZERO_RESULTS) {" & CRLF & _
					 "   var CSV = '';" & CRLF & _
					 "   $.each(results, function (key, result) {" & CRLF & _
					 "    CSV += result.formatted_address + ';';" & CRLF & _
					 "    CSV += result.geometry.location + '\n';" & CRLF & _
					 "   });" & CRLF & _
					 "   b4j_raiseEvent('requestlatlng_onsuccess', {result: CSV})" & CRLF & _
					 "   // b4j_ws.send(JSON.stringify({type: 'event', event: 'RequestLatLng_OnSuccess', params: {result:CSV} }));" & CRLF & _
					 "  } else {" & _
					 "    b4j_raiseEvent('requestlatlng_onerror', {result: 'No results found'})" & CRLF & _
					 "  }" & CRLF & _
					 " } else {" & CRLF & _
					 "   b4j_raiseEvent('requestlatlng_onerror', {result: 'Geocode was not successful for the following reason: ' + status})" & CRLF & _
					 " }" & CRLF & _
					 "});"	

	mWS.Eval(Script, Array As Object(Address))
	
End Sub

Sub SetMarkerInfoWindow(Position As Int, Content As String, AutoOpen As Boolean)

	Dim Script As String

	Script = "var myMap = $(arguments[0]).data('googlemap');" & _
					 "var myMarkerArray = $(arguments[0]).data('markerarray');" & _
					 "var myMarker = myMarkerArray[arguments[1]];" & _
					 "var myInfoWindow = new google.maps.InfoWindow();" & _
					 "myInfoWindow.setContent(arguments[2]);" & _
					 "google.maps.event.addListener(myMarker, 'click', function () {myInfoWindow.open(myMap, myMarker)});"
					 
	If AutoOpen = True Then
		Script = Script & "myInfoWindow.open(myMap, myMarker);"
	End If 

	mWS.Eval(Script, Array As Object("#" & mID, Position, Content))
	
End Sub

Sub SetMarkerTitle(Position As Int, Title As String)

	Dim Script As String

	Script = "var myMap = $(arguments[0]).data('googlemap');" & _
					 "var myMarkerArray = $(arguments[0]).data('markerarray');" & _
					 "var myMarker = myMarkerArray[arguments[1]];" & _
					 "myMarker.setTitle(arguments[2]);"
					 
	mWS.Eval(Script, Array As Object("#" & mID, Position, Title))

End Sub

Sub GetVisible() As Future
	Return mWS.EvalWithResult("return ($(arguments[0]).css('display')!='none')", Array As Object("#" & mID))
End Sub
Sub SetVisible(Visible As Boolean)
	If Visible = True Then
		SetCss("display", "")
	Else
		SetCss("display", "none")
	End If
End Sub

Sub Refresh()

	mWS.Eval("google.maps.event.trigger( $(arguments[0]).data('googlemap') , 'resize')", Array As Object("#" & mID))

End Sub

' ######################

Sub Resize(Left As String, Top As String, Width As String, Height As String)

	Dim CSS As String

	CSS = "$(arguments[0]).css({"
	
	If Left   <> -1 Then CSS = CSS & "'left':'" & Left & "px',"
	If Top    <> -1 Then CSS = CSS & "'top':'" & Top & "px',"
	If Width  <> -1 Then CSS = CSS & "'width':'" & Width & "px',"
	If Height <> -1 Then CSS = CSS & "'height':'" & Height & "px',"
	
	If CSS.EndsWith(",") Then	
	
		CSS = CSS.SubString2(0, CSS.Length - 1)
	
		CSS = CSS & "});"
	
		mWS.Eval(CSS, Array As Object("#" & mID))
		
		mWS.Eval("google.maps.event.trigger( $(arguments[0]).data('googlemap') , 'resize')", Array As Object("#" & mID))
		
	End If
	
End Sub

Sub GetTop() As Future
	Return GetCss("top")
End Sub
Sub SetTop(Top As String)
	SetCss("top", Top & "px")
End Sub

Sub GetLeft As Future
	Return GetCss("left")
End Sub
Sub SetLeft(Left As String)
	SetCss("left", Left & "px")
End Sub

Sub GetWidth As Future
	Return GetCss("width")
End Sub
Sub SetWidth(Width As String)
	SetCss("width", Width)
End Sub

Sub GetHeight As Future
	Return GetCss("height")
End Sub
Sub SetHeight(Height As String)
	SetCss("height", Height)
End Sub

' ######################

Sub GetCss(Property As String) As Future
	Return mWS.GetElementBySelector("#" & mID).GetCss(Property)
End Sub
Sub SetCss(Property As String, Value As String)
	mWS.GetElementBySelector("#" & mID).SetCss(Property, Value)
End Sub

Sub GetAttr(Property As String) As Future
	Return mWS.EvalWithResult("return $(arguments[0]).attr(arguments[1])", Array As Object("#" & mID, Property))
End Sub
Sub SetAttr(Property As String, Value As String)
	mWS.Eval("$(arguments[0]).attr(arguments[1], arguments[2])", Array As Object("#" & mID, Property, Value))
End Sub

Sub GetProp(Property As String) As Future
	Return mWS.GetElementBySelector("#" & mID).GetProp(Property)
End Sub
Sub SetProp(Property As String, Value As String)
	mWS.GetElementBySelector("#" & mID).SetProp(Property, Value)
End Sub

